@echo off
setlocal

set archiver=rar32 a -as -m5 -mm -rr -r -s
set srcrootdir=%cd%
if "%2" == "" (
	set binrootdir=psiwin
) else (
	set binrootdir=%2
)
set srcoutdir=%temp%\psisrc

set delfile=del /f /q
set deldir=rmdir /s /q
set copyfile=copy
set copydir=xcopy /c /e /h /i /q


set year=%date:~0,4%
set month=%date:~5,2%
set day=%date:~8,2%


set psiname=psi
set psiversion=0.12
if "%1" == "" (
	set psirelease=darcs
) else (
	set psirelease=%1
)
set srcoutdir=%srcoutdir%.%psirelease%

set qtname=qt4
set qtversion=4.2.3

set opensslname=openssl
set opensslversion=0.9.8g


set coreother=other


set mainarchive=%srcrootdir%\%psiname%-%psiversion%
set core=%mainarchive%-core
set resources=%mainarchive%-resources
set addons=%mainarchive%-addons
set wholebin=%mainarchive%
if not "%psirelease%" == "" (
	set wholebin=%wholebin%-%psirelease%
)
set wholebin=%wholebin%-%year%%month%%day%
set wholesrc=%wholebin%-src


set application=%core%-application-%year%%month%%day%
if not "%psirelease%" == "" (
	set application=%application%-%psirelease%
)
set qt=%core%-%qtname%-%qtversion%
set openssl=%core%-%opensslname%-%opensslversion%
set coregraphics=%core%-graphics
set coreother=%core%-other

set iconsets=%resources%-iconsets
set sounds=%resources%-sounds

set aspell=%addons%-aspell
set aspellcore=%aspell%-core
set dictpl=%aspell%-pl
set dicten=%aspell%-en
set dictde=%aspell%-de

set gifsupport=%addons%-gifsupport-%qtversion%

set snarlplugin=%addons%-snarlplugin

set translation=%addons%-translation
set translationpl=%translation%-pl-%year%%month%%day%



echo         Packaging Psi...

pushd %binrootdir%

set /a step=1
echo         %step%. Core packages:
echo            * Application
title Packaging Psi: core/application
%archiver% %application%.rar psi.exe > nul

echo            * Qt4
title Packaging Psi: core/qt4
%archiver% %qt%.rar qt*4.dll > nul

echo            * OpenSSL
title Packaging Psi: core/openssl
%archiver% %openssl%.rar *eay32.dll > nul

echo            * Graphics
title Packaging Psi: core/graphics
%archiver% %coregraphics%.rar iconsets\roster\default iconsets\system\default > nul

echo            * MinGW runtime, idleui.dll, Aspell engine, certs, text
title Packaging Psi: core/other
%archiver% %coreother%.rar mingwm10.dll idleui.dll aspell-15.dll certs copying readme.txt > nul


set /a step=((%step% + 1))
echo         %step%. Resource packages:
echo            * Iconsets
title Packaging Psi: resources/iconsets
%archiver% %iconsets%.rar -xiconsets\roster\default -xiconsets\system\default iconsets > nul

echo            * Sounds
title Packaging Psi: resources/sounds
%archiver% %sounds%.rar sound > nul


set /a step=((%step% + 1))
echo         %step%. Add-on packages:
echo            * Aspell dictionaries
echo              - Core
title Packaging Psi: addons/aspell/core
%archiver% %aspellcore%.rar aspell\data\*scii.dat aspell\data\*.kbd aspell\data\iso8859*.* aspell\data\koi8*.* aspell\data\standard.kbd > nul
echo              - Polish
title Packaging Psi: addons/aspell/Polish
%archiver% %dictpl%.rar aspell\data\pl*.* aspell\dict\pl*.* aspell\dict\polish*.* > nul
echo              - English
title Packaging Psi: addons/aspell/English
%archiver% %dicten%.rar aspell\data\en*.* aspell\dict\en*.* aspell\dict\american*.* aspell\dict\british*.* aspell\dict\canadian*.* aspell\dict\english*.* > nul
echo              - German
title Packaging Psi: addons/aspell/German
%archiver% %dictde%.rar aspell\data\de*.* aspell\dict\de*.* aspell\dict\deutsch*.* aspell\dict\german*.* aspell\dict\swiss*.* > nul

echo            * Qt4 image plugins
title Packaging Psi: addons/gifsupport
%archiver% %gifsupport%.rar imageformats > nul

echo            * Psi Snarl plugin
title Packaging Psi: addons/snarlplugin
%archiver% %snarlplugin%.rar plugins\snarlplugin.dll > nul

echo            * Psi and Qt4 translations
echo              - Polish
title Packaging Psi: addons/translations/Polish
%archiver% %translationpl%.rar psi_pl.qm qt_pl.qm > nul


set /a step=((%step% + 1))
echo         %step%. Whole application (without plugins and dictionaries)
title Packaging Psi: binaries
%archiver% %wholebin%.rar -xplugins -xaspell -xaspell.disabled -xpsiwin_package.bat > nul

popd
pushd %srcrootdir%

set /a step=((%step% + 1))
echo         %step%. Application sources
title Packaging Psi: sources
echo            * Copying current sources 
if exist %srcoutdir% %deldir% %srcoutdir%
mkdir %srcoutdir%
%copydir% . %srcoutdir% > nul
pushd %srcoutdir%
echo            * Clearing sources and removing unwanted files
%deldir% %binoutdir% > nul
%delfile% *.exe > nul
%delfile% *.rar > nul
call makewin_clean.bat > nul
echo            * Packaging sources
%archiver% %wholesrc%.rar > nul
popd
echo            * Removing source copy
%deldir% %srcoutdir% > nul

popd

echo         Done.
title
endlocal
